@@ -17,13 +17,13 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * $Id: i18n.cpp 128 2008-03-28 22:28:49Z tom $
+ * $Id: i18n.cpp 167 2008-11-30 00:03:32Z tom $
  *
  *
  * Translations provided by:
  *
- * Spanish     bittor from open7x0.org
  * Italian     Diego Pierotto <vdr-italian@tiscali.it>
+ * Spanish     Bittor Corl <bittor7x0 _at_ gmail.com>
  *
  */
 
@@ -147,14 +147,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { "Custom", // English
     "Benutzerdefiniert", // Deutsch / German
     "", // Slovenski / Slovenian
-    "Personalizzata", // Italiano / Italian
+    "Personale", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Seleccionar", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -169,14 +169,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { " Deck count", // English
     " Blatt-Anzahl", // Deutsch / German
     "", // Slovenski / Slovenian
-    " Conteggio mazzo", // Italiano / Italian
+    " Numero mazzi", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    " Contar baraja", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -191,14 +191,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { " Pile count", // English
     " Anzahl Reihen", // Deutsch / German
     "", // Slovenski / Slovenian
-    " Conteggio mucchio", // Italiano / Italian
+    " Numero mucchi", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    " Contar montn", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -213,14 +213,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { " Deal count", // English
     " Neue Karten geben", // Deutsch / German
     "", // Slovenski / Slovenian
-    " Conteggio mano", // Italiano / Italian
+    " Numero mani", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    " Contar reparto", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -242,7 +242,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Posicin OSD izquierda", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -264,7 +264,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Posicin OSD superior", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -286,7 +286,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Anchura OSD", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -308,7 +308,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Altura OSD", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -330,7 +330,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Error compensacin OSD", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -345,14 +345,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { "Shrink height", // English
     "Hhe verringern", // Deutsch / German
     "", // Slovenski / Slovenian
-    "Ridimensiona altezza", // Italiano / Italian
+    "Ridim. altezza", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Encoger altura", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -367,14 +367,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { "Shrink width", // English
     "Breite verringern", // Deutsch / German
     "", // Slovenski / Slovenian
-    "Ridimensiona larghezza", // Italiano / Italian
+    "Ridim. larghezza", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Encoger anchura", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -389,14 +389,14 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
   { "Shrink width and height", // English
     "Breite und Hhe verringern", // Deutsch / German
     "", // Slovenski / Slovenian
-    "Ridimensiona larghezza e altezza", // Italiano / Italian
+    "Ridim. larghezza e altezza", // Italiano / Italian
     "", // Nederlands / Dutch
     "", // Portugus / Portuguese
     "", // Franais / French
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Encoger anchura y altura", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -418,7 +418,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Reducir colores", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -440,7 +440,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Ocultar fila superior", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
@@ -462,7 +462,7 @@ const tI18nPhrase SpiderPlugin::Phrases[] = {
     "", // Norsk / Norwegian
     "", // suomi / Finnish
     "", // Polski / Polish
-    "", // Espaol / Spanish
+    "Reiniciar", // Espaol / Spanish
     "", //  / Greek
     "", // Svenska / Swedish
     "", // Romn / Romanian
